BIP-85 deterministic entropy generation
Derives entropy from the extended private key according to BIP-85.
Examples
There are a few examples in the repository.
Optional features
By default the library can derive entropy in any format specified by the standard except mnemonics. To use mnemonics enable feature “mnemonic”.
All bip-39 languages except english are also optional, so if you plan generating mnemonics in japanese enable feature “japanese”, and so on.
Re-exports
Re-exports
pub use error::Error;pub use drng::*;pub use hex::*;pub use mnemonic::*;pub use pwd_base64::*;pub use pwd_base85::*;pub use wif::*;pub use xprv::*;
Modules
Functions
- derive
- Derive raw bytes from the root inner using provided derivation path.